@@ -23,7 +23,7 @@ class get_player:
 
 		if not name == None:
 			uuid = get_uuid(name)
-		response = requests.get(f"{HYPIXEL_API}/player?key=d44a57f7-ebe1-4b05-9370-9db9c94d9464&uuid={uuid}")
+		response = requests.get(f"{HYPIXEL_API}/player?key={self.api}&uuid={uuid}")
 		json = response.json()
 
 		if not json["success"]:
